aboutsummaryrefslogtreecommitdiff
path: root/libbpkg/manifest.hxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2024-01-31 18:17:59 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2024-02-02 10:28:10 +0300
commitc3158b221ef94b4f2c0d2a67aebcce22acf50993 (patch)
tree5f7e2da546e2e4df4c83c15360c36e4e20361198 /libbpkg/manifest.hxx
parentb836f4966224424649de3e1dde1bca39888d9ed9 (diff)
Add support for enable clause in tests package manifest value
Diffstat (limited to 'libbpkg/manifest.hxx')
-rw-r--r--libbpkg/manifest.hxx7
1 files changed, 5 insertions, 2 deletions
diff --git a/libbpkg/manifest.hxx b/libbpkg/manifest.hxx
index 8439cdf..834b681 100644
--- a/libbpkg/manifest.hxx
+++ b/libbpkg/manifest.hxx
@@ -1083,6 +1083,7 @@ namespace bpkg
{
test_dependency_type type;
bool buildtime;
+ butl::optional<std::string> enable;
butl::optional<std::string> reflect;
test_dependency () = default;
@@ -1090,15 +1091,17 @@ namespace bpkg
test_dependency_type t,
bool b,
butl::optional<version_constraint> c,
+ butl::optional<std::string> e,
butl::optional<std::string> r)
: dependency {std::move (n), std::move (c)},
type (t),
buildtime (b),
+ enable (std::move (e)),
reflect (std::move (r)) {}
// Parse the test dependency string representation in the
// `[*] <name> [<version-constraint>] [<reflect-config>]` form. Throw
// std::invalid_argument if the value is invalid.
//
// Verify that the reflect clause, if present, refers to the test
// dependency package configuration variable. Note that such variable
@@ -1090,15 +1091,17 @@ namespace bpkg
reflect (std::move (r)) {}
// Parse the test dependency string representation in the
- // `[*] <name> [<version-constraint>] [<reflect-config>]` form. Throw
- // std::invalid_argument if the value is invalid.
+ // `[*] <name> [<version-constraint>] ['?' <enable-condition>] [<reflect-config>]`
+ // form. Throw std::invalid_argument if the value is invalid.
//
// Verify that the reflect clause, if present, refers to the test